==> AppliStation-1.3.2b1.zip: resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by resource.rc
//
#define IDS_PROGRESS_COMPRESS           1
#define IDS_PROGRESS_DECOMPRESS         2
#define IDS_PROGRESS_EXTRACT            2
#define IDS_PROGRESS_DELETE             3
#define IDS_PROGRESS_UPDATE             4
#define IDS_DECRYPT                     5
#define IDS_ENCRYPT                     6
#define IDS_PROPERTY                    7
#define IDS_VALUE                       8
#define IDS_COUNT_DOWN                  9
#define IDS_PROCESS_FILE_SIZE           10
#define IDS_FILE_TYPE                   11
#define IDS_WRITE_TIME                  12
#define IDS_ATTRIBUTE                   13
#define IDS_RATIO                       14
#define IDS_METHOD                      15
#define IDS_CRC                         16
#define IDD_PROGRESS                    101
#define IDD_CONFIG                      102
#define IDD_PASSWORD                    103
#define IDD_CONFIRMATION                104
#define IDD_SFX                         105
#define IDR_7ZSDJC                      116
#define IDB_YES                         1001
#define IDB_NO                          1002
#define IDB_YES_ALL                     1003
#define IDB_NO_ALL                      1004
#define IDB_AUTO_RENAME                 1005
#define IDE_PASSWORD                    1010
#define IDC_MASK                        1011
#define IDS_REPLACE                     1014
#define IDS_VERSION                     1016
#define IDS_OLD_ICON                    1023
#define IDS_NEW_ICON                    1024
#define IDS_OLD_FILE_INFO               1025
#define IDS_NEW_FILE_INFO               1026
#define IDP_PROGRESS                    1028
#define IDS_WORK_FILE                   1029
#define IDS_PROCESS_SIZE                1030
#define IDS_ARCHIVE_FILE                1031
#define IDE_TITLE                       1035
#define IDE_BEGIN_PROMPT                1036
#define IDE_RUN_PROGRAM                 1037
#define IDC_PROGRESS                    1038
#define IDE_DIRECTORY                   1039
#define IDE_EXECUTE_FILE                1040
#define IDE_EXECUTE_PARAMETERS          1041
#define IDC_IS_INSTALLER                1047
#define IDB_DETAIL                      1051
#define IDC_DETAIL                      1052
#define IDL_DETAIL                      1053

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NO_MFC                     1
#define _APS_NEXT_RESOURCE_VALUE        119
#define _APS_NEXT_COMMAND_VALUE         40001
#define _APS_NEXT_CONTROL_VALUE         1054
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif

==> AppliStation-1.4.1.zip: resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by resource.rc
//
#define IDS_PROGRESS_COMPRESS           1
#define IDS_PROGRESS_DECOMPRESS         2
#define IDS_PROGRESS_EXTRACT            2
#define IDS_PROGRESS_DELETE             3
#define IDS_PROGRESS_UPDATE             4
#define IDS_DECRYPT                     5
#define IDS_ENCRYPT                     6
#define IDS_PROPERTY                    7
#define IDS_VALUE                       8
#define IDS_COUNT_DOWN                  9
#define IDS_PROCESS_FILE_SIZE           10
#define IDS_FILE_TYPE                   11
#define IDS_WRITE_TIME                  12
#define IDS_ATTRIBUTE                   13
#define IDS_RATIO                       14
#define IDS_METHOD                      15
#define IDS_CRC                         16
#define IDS_ELAPSED_TIME                17
#define IDS_PROCESSING_SPEED            18
#define IDS_ENTER_PASSWORD              19
#define IDD_PROGRESS                    101
#define IDD_CONFIG                      102
#define IDD_PASSWORD                    103
#define IDD_CONFIRMATION                104
#define IDD_SFX                         105
#define IDR_7ZSDJC                      116
#define IDB_YES                         1001
#define IDB_NO                          1002
#define IDB_YES_ALL                     1003
#define IDB_NO_ALL                      1004
#define IDB_AUTO_RENAME                 1005
#define IDE_PASSWORD                    1010
#define IDC_MASK                        1011
#define IDS_REPLACE                     1014
#define IDS_VERSION                     1016
#define IDS_OLD_ICON                    1023
#define IDS_NEW_ICON                    1024
#define IDS_OLD_FILE_INFO               1025
#define IDS_NEW_FILE_INFO               1026
#define IDP_PROGRESS                    1028
#define IDS_WORK_FILE                   1029
#define IDS_PROCESS_SIZE                1030
#define IDS_ARCHIVE_FILE                1031
#define IDE_TITLE                       1035
#define IDE_BEGIN_PROMPT                1036
#define IDE_RUN_PROGRAM                 1037
#define IDC_PROGRESS                    1038
#define IDE_DIRECTORY                   1039
#define IDE_EXECUTE_FILE                1040
#define IDE_EXECUTE_PARAMETERS          1041
#define IDC_IS_INSTALLER                1047
#define IDB_DETAIL                      1051
#define IDC_DETAIL                      1052
#define IDL_DETAIL                      1053
#define IDC_BACK_GROUND                 1055

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NO_MFC                     1
#define _APS_NEXT_RESOURCE_VALUE        119
#define _APS_NEXT_COMMAND_VALUE         40001
#define _APS_NEXT_CONTROL_VALUE         1057
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
